@@ -12,6 +12,7 @@
 #include <sys/time.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
+#include <stdlib.h>
 
 #ifdef __linux__
 #include <sys/prctl.h>
@@ -240,8 +241,10 @@ SEXP R_eval_fork(SEXP call, SEXP env, SEXP subtmp, SEXP timeout, SEXP outfun, SE
 
     //Linux only: try to kill proccess group when parent dies
 #ifdef PR_SET_PDEATHSIG
-    prctl(PR_SET_PDEATHSIG, SIGTERM);
-    signal(SIGTERM, kill_process_group);
+    if(getenv("KILL_ORPHAN_FORKS")){
+      prctl(PR_SET_PDEATHSIG, SIGTERM);
+      signal(SIGTERM, kill_process_group);      
+    }
 #endif
 
     //this is the hacky stuff
